// $Id: coding.cpp 7014 2019-03-31 16:28:41Z flaterco $

/*  Deal with character coding in Harmonic database. */

/*****************************************************************************\

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

\*****************************************************************************/



#define __STDC_FORMAT_MACROS
#include "map.h"
#include <assert.h>


//  Convert string read from Harmonic database to QString
//  Character set conversion should happen here
//  This version is for Latin1 coding

QString fromHarmonic (const char *from)
{
    return QString (QLatin1String (from));
}

//  Prepare QString for write to or use in Harmonic database
//  Character set conversion should happen here
//  This version is for Latin1 coding

void toHarmonic (char *to, QString from, unsigned bufsize)
{
    assert (to);
    assert (bufsize > 0);
    strncpy (to, from.toLatin1(), bufsize-1);
    to[bufsize-1] = '\0';
}

void toHarmonic (char *to, QLineEdit *from, unsigned bufsize)
{
    toHarmonic (to, from->text (), bufsize);
}

void toHarmonic (char *to, QPlainTextEdit *from, unsigned bufsize)
{
    toHarmonic (to, from->toPlainText (), bufsize);
}
