// $Id: tideDialogHelp.h 7016 2019-03-31 17:15:37Z flaterco $

/*****************************************************************************\

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

\*****************************************************************************/


#include "icon_inferred.xpm"

// If there is embedded HTML, lines are wrapped to make a compact text box.
// If not, the line goes clear across the screen.  So if a line gets too
// long, add an HTML no-op like wrapping it in <div> tags.  Just more Qt
// weirdness.

// DWF 2007-04:  Counterintuitive trick needed to quote an integer constant.
#define _stringify(x) #x
#define stringify(x) _stringify(x)

const char *tideDialogText = "<div>This dialog allows you to update, add, or "
  "delete a tide station record.  Pressing the OK button will save all "
  "changes made to this record to the database.  Pressing the Cancel button "
  "will discard all changes.  You can delete a record using the Delete Record "
  "button.</div>";
const char *recnumText = "This is the record number in the tide constituent "
  "database.  It is for information only and is not editable.";
const char *refText = "This is the reference station name for this "
  "subordinate record.  It is for information only and is not editable.";
const char *nameText = "This is the name of the station.  Field length is "
  stringify(ONELINER_LENGTH) " characters, minus one for the required null "
  "terminator.";
const char *latText = "This is the latitude of the station.  It will be "
  "displayed in the format selected in the <b>Preferences</b> menu.  The "
  "latitude may be entered in any of the following formats:<br><br>"
  "        Hemisphere Degrees Minutes Seconds.decimal<br>"
  "        Hemisphere Degrees Minutes.decimal<br>"
  "        Hemisphere Degrees.decimal<br>"
  "        SignDegrees Minutes Seconds.decimal<br>"
  "        SignDegrees Minutes.decimal<br>"
  "        SignDegrees.decimal<br><br>"
  "South is negative.";
const char *lonText = "This is the longitude of the station.  It will be "
  "displayed in the format selected in the <b>Preferences</b> menu.  The "
  "longitude may be entered in any of the following formats:<br><br>"
  "        Hemisphere Degrees Minutes Seconds.decimal<br>"
  "        Hemisphere Degrees Minutes.decimal<br>"
  "        Hemisphere Degrees.decimal<br>"
  "        SignDegrees Minutes Seconds.decimal<br>"
  "        SignDegrees Minutes.decimal<br>"
  "        SignDegrees.decimal<br><br>"
  "West is negative.";
const char *sourceText = "This is the source of the station data.  Field "
  "length is " stringify(ONELINER_LENGTH) " characters, minus one for the "
  "required null terminator.";
const char *station_id_contextText = "This is the context of the Station "
  "ID.  Field length is " stringify(ONELINER_LENGTH) " characters, minus "
  "one for the required null terminator.";
const char *station_idText = "This is the unique identifier of the station "
  "within the specified context.  Field length is " stringify(ONELINER_LENGTH)
  " characters, minus one for the required null terminator.";
const char *legaleseText = "This is a high priority notice for the station data.  It will be appended to the station name in XTide.";
const char *tzfileText = "This is the time zone in which predictions for the station should be rendered.";
const char *countryText = "This is the country in which the station is located.";
const char *restrictionText = "This specifies the acceptable use of the tide "
  "data for this station.  If you set it to <b>public domain</b>, it means "
  "that anybody can steal your data for any purpose.";
const char *commentsText = "This is the comments field for the station. "
  "Comments are only provided to the user if the user requests them.  "
  "Field length is " stringify(MONOLOGUE_LENGTH) " characters, minus one "
  "for the required null terminator.  You can allow the text to wrap or use "
  "the <b>Enter</b> key to start new lines.  Blank lines are accepted.";
const char *notesText = "This is the notes field for the station. "
  "Notes are included at the top of output when possible. "
  "Field length is " stringify(MONOLOGUE_LENGTH) " characters, minus one "
  "for the required null terminator.  You can allow the text to wrap or use "
  "the <b>Enter</b> key to start new lines.  Blank lines are accepted.";
const char *xfieldsText = "This is the X-fields field for the station. "
  "It is used to wedge in additional 'extension fields' that are not "
  "otherwise supported by the TCD format.  Field length is "
  stringify(MONOLOGUE_LENGTH) " characters, minus one for the required null "
  "terminator.  The format of this field is rigidly defined in the libtcd "
  "documentation.  Simple example:<br><br>"
  "My New Field:Value blah blah<br>"
  "Some Other Field:Value blah blah blah blah,<br>"
  "&nbsp;continuation line blah blah.<br>"
  "Yet another field:Etc.";
const char *datumText = "This is the description of which tidal datum is being used. "
  "In the U.S., it is usually <b>Mean Lower Low Water</b>. "
  "For currents this field is irrelevant.";
const char *datum_offsetText = "For tides, this is the elevation of Mean Sea "
  "Level (MSL) relative to the specified datum in Level Units.  For "
  "currents it is an analogous constant used to calibrate the velocity of "
  "the predicted currents against zero.";
const char *confidenceText = "Confidence is a meaningless indicator of data "
  "quality ranging between 0 and 15 and normally initialized to 10.";
const char *zone_offsetText = "This is the standard time to which epochs are adjusted, a.k.a. the meridian, in hours and minutes east of UTC.  The format is +/-HHMM.  Do not use daylight "
  "savings time.";
const char *expiration_dateText = "This is the expiration date for this "
  "data set.  The format is YYYYMMDD.  Unknown is indicated by a blank.";
const char *date_importedText = "This is the date that this station was "
  "imported into the database.  The format is YYYYMMDD.  Unknown is "
  "indicated by a blank.";
const char *monthsText = "This is the number of months of tide data that were "
  "used to calculated the harmonic constants for this station.  Unknown is indicated by a blank.";
const char *ldosText = "This is the last date in the time series that was "
  "used to calculate the harmonic constants for this station.  The format is YYYYMMDD.  Unknown is indicated by a blank.";
const char *constituentsText = "This table contains all of the amplitude and "
  "epoch data for this station.  The constituent names are not editable. "
  "Blank fields are undefined.  To edit a field double-click in the field.  "
  "To remove a constituent replace the values with blanks.  Fields containing "
  "a <img source=\":/icon_inferred.xpm\"> are inferred constituents. They are there "
  "mostly for information and are not actually stored in the database.  They "
  "are computed \'on-the-fly\'.  If you modify one of these values it "
  "<i><b>will</b></i> be saved to the database and will no longer be treated "
  "as an inferred constituent.";
const char *level_unitsText = "This is the units field for all heights or "
  "speeds.  This is usually <b>meters</b> or <b>feet</b> but, in the case of "
  "a current, may be <b>knots</b> or <b>knots^2</b>.";
const char *direction_unitsText = "This is the units field for the <b>Ebb "
  "Direction</b> and <b>Flood Direction</b> fields.";
const char *min_time_addText = "This is the minimum time corrector for the "
  "station.  The format is +/-HHMM.  Blank indicates unknown and is equivalent to the value 0.";
const char *min_level_addText = "This is the minimum level corrector (in the "
  "specified units) for the station.  Blank indicates unknown and is equivalent to the value 0.";
const char *min_level_multText = "This is the minimum level multiplier for "
  "the station.  Blank indicates unknown and is equivalent to the value 1.";
const char *min_directionText = "This is the direction of the maximum ebb current.  Enter a number between 0 and 359, or leave blank for unknown or not applicable.";
const char *max_time_addText = "This is the maximum time corrector for the "
  "station.  The format is +/-HHMM.  Blank indicates unknown and is equivalent to the value 0.";
const char *max_level_addText = "This is the maximum level corrector (in the "
  "specified units) for the station.  Blank indicates unknown and is equivalent to the value 0.";
const char *max_level_multText = "This is the maximum level multiplier for "
  "the station.  Blank indicates unknown and is equivalent to the value 1.";
const char *max_directionText = "This is the direction of the maximum flood current.  Enter a number between 0 and 359, or leave blank for unknown or not applicable.";
const char *flood_beginsText = "This is the time corrector for the beginning "
  "of flood tide for this station, a.k.a. \"minimum before flood.\"  The format is +/-HHMM.  Blank indicates "
  "unknown.  Zero <i>IS NOT</i> the same as unknown.";
const char *ebb_beginsText = "This is the time corrector for the beginning "
  "of ebb tide for this station, a.k.a. \"minimum before ebb.\"  The format is +/-HHMM.  Blank indicates "
  "unknown.  Zero <i>IS NOT</i> the same as unknown.";
const char *subListText = "This dialog displays a list of subordinate "
  "stations for the selected reference station.  It also allows you to change "
  "the reference station for one or more of the listed subordinate stations.  "
  "You can use all of the standard <i><b>Extended</b></i> list selection "
  "options to select subordinate stations to have their reference station "
  "changed.  When the user selects an item the selection is cleared and the "
  "new item selected.  However, if the user presses the <b>Ctrl</b> key when "
  "clicking on an item, the clicked item gets toggled and all other items are "
  "left untouched.  And if the user presses the <b>Shift</b> key while "
  "clicking on an item, all items between the current item and the clicked "
  "item get selected or unselected, depending on the state of the clicked "
  "item.  Also, multiple items can be selected by dragging the mouse while "
  "the left mouse button is kept pressed.";
