// $Id: tideEditor.h 7018 2019-03-31 17:57:46Z flaterco $

/* TideEditor class definition.  */

/*****************************************************************************\

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

\*****************************************************************************/


#ifndef TIDEEDITOR_H
#define TIDEEDITOR_H

#include <tcd.h>
#include "map.h"


char *fixpos (double degs, double *deg, double *min, double *sec, char *hem,
	      const char *c_type, const char *c_form);
void posfix (char *string, double *degs, const char *c_type);


typedef struct
{
    int  recnum;
    QString *name;     // QString properly handles non-ASCII
    double latitude;
    double longitude;
} STATION_LIST;


class QToolButton;
class QAction;


class TideEditor;
class TideList;

class TideEditor:public QMainWindow
{
    Q_OBJECT 


  public:

    TideEditor (const char *hfile_in, QWidget *parent = 0, const char *name = 0);
    ~TideEditor ();

    void setRedrawZeroLevel ();
    void redrawMap ();
    void highlightStation (double lat, double lon, unsigned char record_type);

    int size, number_of_records;


    STATION_LIST *station_list;


    char pos_format[10];
      

    TideList *tideList;


    TIDE_RECORD default_rec; // default values inherited from previous edit


  public slots:

    // Public so that when tideList is rudely closed it can call this to
    // close out nicely.
    void slotQuit ();


  protected:

    char hfile[512];

    NV_BOOL readonly;

    Map *map;

    DB_HEADER_PUBLIC db;
    TIDE_RECORD rec;

    QColor refStationColor, subStationColor;
    QButtonGroup *bGrp;
    QGroupBox *bGrpBox;
    QDialog *prefsD, *searchD;
    QListWidget *searchList;
    QLineEdit *searchName;
    int lastrec;

    QToolButton    *bQuit, *bZoomOut, *bReset, *bLeft, *bUp, *bDown, *bRight, 
                   *bPrefs, *bDisaster, *bSearch;

    QSettings settings;

    void plotStations ();
    void envin ();
    void envout ();


  protected slots:

    void slotRedraw ();
    void slotLeftMouse (QMouseEvent * e);
    void slotMidMouse (QMouseEvent * e);
    void slotRightMouse (QMouseEvent * e);
    void slotMouseMove (QMouseEvent * e);

    void slotDisaster ();

    void slotPrefs ();
    void slotPrefsClicked ();
    void slotClosePrefs ();
    void slotCloseSearch ();
    void slotSelected ();
    void slotHighlighted ();
    void slotTextChanged ();
    void slotSearch ();
    void slotRefColor ();
    void slotSubColor ();
    void slotZoomOut ();
    void slotReset ();

    void slotUp ();
    void slotDown ();

    void slotRight ();
    void slotLeft ();

    void about ();
    void aboutQt ();

  protected:
    void keyPressEvent (QKeyEvent * e);
};

#endif
